#
# INTRODUCTION TO R - Tutorial
#===============================================================================


# Search and Help
??csv
help(read.table)


#---------------------------#
# IMPORTING DATA            #
#---------------------------#

# Working Directory
getwd()
setwd("/Users/nadia/Desktop")   #Change working directory


# Importing Data
flights<-read.csv("January 2020 Flights.csv")



#---------------------------#
# EXPLORING DATA            #
#---------------------------#

str(flights)
head(flights)
tail(flights)


# Square Brackets
flights[1,5]
flights[1,"originstate"]
flights[1, 1:5]
flights[1000:1005,c("originstate", "deptime", "depdelay")]


# Variables
originstate
flights$originstate


# Frequency Table
table(flights$depdelay)
table(flights$depdelay, exclude=NULL)


# Two-way Frequency Table
install.packages("gmodels")
library(gmodels)
CrossTable(flights$depdelay, flights$arrdelay)


# Summary Statistics
summary(flights$distance)
summary(flights)
mean(flights$distance)
sd(flights$distance)
summary(flights$distance[flights$dayofweek==1])
by(flights$distance, flights$dayofweek, summary)



#--------------#
# GRAPHS       #
#--------------#

# Bar chart
dayofweektable <- table(flights$dayofweek)
barplot(dayofweektable, main="Frequency of Flights by Day of the Week",  xlab="Day of Week", ylab="Frequency")


# Histogram
hist(flights$deptime, main="Histogram of Departure Time",  xlab="Departure Time", col="lightblue")


# Scatterplot
plot(flights$dayofweek, flights$deptime, pch=3, cex=3, col="darkred")
                                                                                                                                                                                                                                                    



#---------------------------#
# NEW VARIABLES             #
#---------------------------#

# Example 1
flights$distancemiles <- flights$distance*0.621
summary(flights$distance)
summary(flights$distancemiles)


# Example 2
flights$instate<-NA
flights$instate[flights$originstate==flights$deststate] <- 1
flights$instate[flights$originstate!=flights$deststate] <- 0
CrossTable(flights$instate)


# Example 3
flights$delay <- ""
flights$delay[flights$depdelay==0 & flights$arrdelay==0] <- "not delayed"
flights$delay[flights$depdelay==1 & flights$arrdelay==0] <- "delayed at departure"
flights$delay[flights$depdelay==0 & flights$arrdelay==1] <- "delayed at arrival"
flights$delay[flights$depdelay==1 & flights$arrdelay==1] <- "delayed at both"
CrossTable(flights$delay)
flights$delay <- factor(flights$delay, 
                            levels = c("","not delayed", "delayed at departure", "delayed at arrival", "delayed at both"), 
                            ordered=TRUE)
CrossTable(flights$delay) 


# Saving Data
save(flights, file="Flights 2020.RData")


#-------------------#
# MANAGING DATA     #
#-------------------#

# Subsetting
departure<-subset(flights, select=c(originstate, origin, deptime, depdelay, deststate))
hawaii<-subset(flights, flights$deststate=="Hawaii" & flights$dayofmonth==1)


# Merging Data
airlinecodes <- read.csv("airlinecodes.csv")
flightsmerged <- merge(airlinecodes, flights, by="carrier")
CrossTable(flightsmerged$airline, flightsmerged$diverted)


# Converting to Data Frame
origin<-as.data.frame(table(flights$origin))
names(origin)<-c("code", "origin")
dest<-as.data.frame(table(flights$dest))
names(dest)<-c("code", "dest")
airports <-merge(origin, dest, by="code", all=TRUE)
str(airports)

# Exporting Data
write.csv(airports, file="Airports.csv", row.names=FALSE)

